vfbLib.parsers.truetype.VdmxParser
==================================

.. currentmodule:: vfbLib.parsers.truetype

.. autoclass:: VdmxParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~VdmxParser.__init__
      ~VdmxParser.parse
      ~VdmxParser.parse_hex
      ~VdmxParser.read_double
      ~VdmxParser.read_doubles
      ~VdmxParser.read_float
      ~VdmxParser.read_floats
      ~VdmxParser.read_int16
      ~VdmxParser.read_int32
      ~VdmxParser.read_int8
      ~VdmxParser.read_str
      ~VdmxParser.read_str_all
      ~VdmxParser.read_uint16
      ~VdmxParser.read_uint32
      ~VdmxParser.read_uint8
      ~VdmxParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~VdmxParser.encoding
      ~VdmxParser.master_count
      ~VdmxParser.stream
      ~VdmxParser.ttStemsH_count
      ~VdmxParser.ttStemsV_count
   
   